Chromium Code Reviews

Unified Diff: utils/tests/pub/test_pub.dart

Issue 12316056: Move pkg/path to pkg/pathos. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « utils/tests/pub/real_version_test.dart ('k') | utils/tests/pub/validator_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: utils/tests/pub/test_pub.dart
diff --git a/utils/tests/pub/test_pub.dart b/utils/tests/pub/test_pub.dart
index 64ca42391aa6978650c7aa4e5af3c446fdcf4538..823dd129801876a341729630ff9dcaab34417bdd 100644
--- a/utils/tests/pub/test_pub.dart
+++ b/utils/tests/pub/test_pub.dart
@@ -18,7 +18,7 @@ import 'dart:utf';
import '../../../pkg/http/lib/testing.dart';
import '../../../pkg/oauth2/lib/oauth2.dart' as oauth2;
-import '../../../pkg/path/lib/path.dart' as path;
+import '../../../pkg/pathos/lib/path.dart' as path;
import '../../../pkg/unittest/lib/unittest.dart';
import '../../../pkg/yaml/lib/yaml.dart';
import '../../lib/file_system.dart' as fs;
@@ -430,7 +430,7 @@ String _packageName(String sourceName, description) {
case "git":
var url = description is String ? description : description['url'];
// TODO(rnystrom): Using path.basename on a URL is hacky. If we add URL
// support to pkg/path, should use an explicit builder for that.
return path.basename(url.replaceFirst(new RegExp(r"(\.git)?/?$"), ""));
case "hosted":
if (description is String) return description;
@@ -430,7 +430,7 @@ String _packageName(String sourceName, description) {
var url = description is String ? description : description['url'];
// TODO(rnystrom): Using path.basename on a URL is hacky. If we add URL
- // support to pkg/path, should use an explicit builder for that.
+ // support to pkg/pathos, should use an explicit builder for that.
return path.basename(url.replaceFirst(new RegExp(r"(\.git)?/?$"), ""));
case "hosted":
« no previous file with comments | « utils/tests/pub/real_version_test.dart ('k') | utils/tests/pub/validator_test.dart » ('j') | no next file with comments »

Powered by Google App Engine